==> owncloud-10.2.0.zip: owncloud/apps/files_sharing/l10n/sv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server-till-server-delning är inte aktiverat på denna server",
    "The mountpoint name contains invalid characters." : "Monteringspunktens namn innehåller ogiltiga tecken.",
    "Not allowed to create a federated share with the same user server" : "Ej tillåten att skapa en federerad delning med samma användarserver.",
    "Invalid or untrusted SSL certificate" : "Ogiltigt eller ej betrott SSL-certifikat",
    "Could not authenticate to remote share, password might be wrong" : "Kunde ej autensiera fjärrdelningen, lösenordet kan vara fel",
    "Storage not valid" : "Lagring ej giltig",
    "Couldn't add remote share" : "Kunde inte lägga till fjärrutdelning",
    "Shared with you" : "Delat med dig",
    "Shared with others" : "Delat med andra",
    "Shared by link" : "Delad som länk",
    "Uploading..." : "Laddar upp...",
    "Nothing shared with you yet" : "Inget delat med dig ännu",
    "Files and folders others share with you will show up here" : "Filer och mappar andra delar med dig kommer visas här",
    "Nothing shared yet" : "Inget delat ännu",
    "Files and folders you share will show up here" : "Filer och mappar du delar kommer visas här",
    "No shared links" : "Inga delade länkar",
    "Files and folders you share by link will show up here" : "Filer och mappar du delar som länkar kommer visas här",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vill du lägga till fjärrdelning {name} från {owner}@{remote}?",
    "Remote share" : "Fjärrdelning",
    "Remote share password" : "Lösenord för fjärrdelning",
    "Cancel" : "Avbryt",
    "Add remote share" : "Lägg till fjärrdelning",
    "You can upload into this folder" : "Du kan ladda upp i denna map",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ingen OwnCloud Installation (7 eller senare) funnen på {remote}",
    "Invalid ownCloud url" : "Felaktig ownCloud url",
    "Share" : "Dela",
    "No expiration date set" : "Inget utgångsdatum är satt",
    "Shared by" : "Delad av",
    "Sharing" : "Dela",
    "Share API is disabled" : "Dela-API är inaktiverat",
    "Wrong share ID, share doesn't exist" : "Fel delningsid, delning existerar inte",
    "Could not delete share" : "Kunde ej ta bort delning",
    "Please specify a file or folder path" : "Vänligen ange en fil eller sökväg till mapp",
    "Wrong path, file/folder doesn't exist" : "Felaktig sökväg, fil/mapp existerar inte",
    "Please specify a valid user" : "Vänligen ange en giltig användare",
    "Group sharing is disabled by the administrator" : "Gruppdelning är inaktiverat av administratören",
    "Please specify a valid group" : "Vänligen ange en giltig grupp",
    "Public link sharing is disabled by the administrator" : "Publik länkdelning är inaktiverat av administratören",
    "Public upload disabled by the administrator" : "Publik uppladdning är inaktiverad av administratören",
    "Public upload is only possible for publicly shared folders" : "Publik uppladdning är enbart möjligt för publikt delade mappar",
    "Invalid date, date format must be YYYY-MM-DD" : "Ogiltigt datum, datumformat måste vara YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delning %s misslyckades därför att \"back-end-sidan\" inte tillåter delningar av typen %s",
    "Unknown share type" : "Okänd delningstyp",
    "Not a directory" : "Inte en mapp",
    "Could not lock path" : "Kunde inte låsa sökväg",
    "Can't change permissions for public share links" : "Kan inte ändra rättigheter på publika delningslänkar",
    "Wrong or no update parameter given" : "Fel eller ingen uppdateringsparameter angiven",
    "Cannot increase permissions" : "Kan inte öka rättigheter",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En publikt delad fil eller mapp blev <strong>nerladdad</strong>",
    "You received a new remote share %2$s from %1$s" : "Du har mottagit en fjärrdelning %2$s från %1$s",
    "You received a new remote share from %s" : "Du mottog en ny fjärrdelning från %s",
    "%1$s accepted remote share %2$s" : "%1$s accepterade fjärrdelning %2$s",
    "%1$s declined remote share %2$s" : "%1$s nekade fjärrdelning %2$s",
    "%1$s unshared %2$s from you" : "%1$s tog bort delningen %2$s från dig",
    "Public shared folder %1$s was downloaded" : "Publikt delad mapp %1$s blev nerladdad",
    "Public shared file %1$s was downloaded" : "Publikt delad fil %1$s blev nerladdad",
    "You shared %1$s with %2$s" : "Du delade %1$s med %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s delade %1$s med %3$s",
    "You removed the share of %2$s for %1$s" : "Du tog bort delning av %2$s för %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s tog bort delningen av %3$s för %1$s",
    "You shared %1$s with group %2$s" : "Du delade %1$s med grupp %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delade %1$s med gruppen %3$s",
    "You removed the share of group %2$s for %1$s" : "Du tog bort delningen av gruppen %2$s för %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s tog bort delningen av grupp %3$s för %1$s",
    "%2$s shared %1$s via link" : "%2$s delade %1$s via länk",
    "You shared %1$s via link" : "Du delade %1$s via länk",
    "You removed the public link for %1$s" : "Du tog bort den publika länken för %1$s",
    "%2$s removed the public link for %1$s" : "%2$s tog bort den publika länken för %1$s",
    "Your public link for %1$s expired" : "Din publika länk för %1$s har löpt ut",
    "The public link of %2$s for %1$s expired" : "Den publika länken för %2$s av %1$s har löpt ut",
    "%2$s shared %1$s with you" : "%2$s delade %1$s med dig",
    "%2$s removed the share for %1$s" : "%2$s tog bort delningen av %1$s",
    "Downloaded via public link" : "Nerladdad via publik länk",
    "Shared with %2$s" : "Delad med %2$s",
    "Shared with %3$s by %2$s" : "Delad med %3$s av %2$s",
    "Removed share for %2$s" : "Tog bort delningen för %2$s",
    "%2$s removed share for %3$s" : "%2$s tog bort delningen för %3$s",
    "Shared with group %2$s" : "Delning med grupp %2$s",
    "Shared with group %3$s by %2$s" : "Delade med grupp %3$s av %2$s",
    "Removed share of group %2$s" : "Tog bort delning av grupp %2$s",
    "%2$s removed share of group %3$s" : "%2$s tog bort delningen av grupp %3$s",
    "Shared via link by %2$s" : "Delad via länk av %2$s",
    "Shared via public link" : "Delad via publik länk",
    "Removed public link" : "Tog bort publik länk",
    "%2$s removed public link" : "%2$s tog bort publik länk",
    "Public link expired" : "Tidsgräns för publik länk har löpt ut",
    "Public link of %2$s expired" : "Tidsgräns för publik länk för %2$s har löpt ut",
    "Shared by %2$s" : "Delad av %2$s",
    "Shares" : "Delningar",
    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Password" : "Lösenord",
    "No entries found in this folder" : "Inga filer hittades i denna mapp",
    "Name" : "Namn",
    "Share time" : "Delningstid",
    "Expiration date" : "Utgångsdatum",
    "Sorry, this link doesn’t seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the item was removed" : "objektet togs bort",
    "the link expired" : "giltighet för länken har gått ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more info, please ask the person who sent this link." : "För mer information, kontakta den person som skickade den här länken.",
    "%s is publicly shared" : "%s är publikt delad",
    "Add to your ownCloud" : "Lägg till i din ownCloud",
    "Download" : "Ladda ner",
    "Download %s" : "Ladda ner %s",
    "Direct link" : "Direktlänk",
    "Anonymous upload" : "Anonym uppladdning",
    "Uploaded files" : "Uppladdade filer",
    "Click to select files or use drag & drop to upload" : "Klicka för att välja filer eller använd drag-och-släpp för att ladda upp",
    "Cannot remove all permissions" : "Kan inte ta bort alla rättigheter",
    "Pending" : "Väntar",
    "Accept" : "Acceptera",
    "Decline" : "Neka",
    "Declined" : "Nekad",
    "Public link" : "Publik länk"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files_sharing/l10n/sv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server-till-server-delning är inte aktiverat på denna server",
    "The mountpoint name contains invalid characters." : "Monteringspunktens namn innehåller ogiltiga tecken.",
    "Not allowed to create a federated share with the same user server" : "Ej tillåten att skapa en federerad delning med samma användarserver.",
    "Invalid or untrusted SSL certificate" : "Ogiltigt eller ej betrott SSL-certifikat",
    "Could not authenticate to remote share, password might be wrong" : "Kunde ej autensiera fjärrdelningen, lösenordet kan vara fel",
    "Storage not valid" : "Lagring ej giltig",
    "Couldn't add remote share" : "Kunde inte lägga till fjärrutdelning",
    "Shared with you" : "Delat med dig",
    "Shared with others" : "Delat med andra",
    "Shared by link" : "Delad som länk",
    "Anonymous upload" : "Anonym uppladdning",
    "Click to select files or use drag & drop to upload" : "Klicka för att välja filer eller använd drag-och-släpp för att ladda upp",
    "Uploaded files" : "Uppladdade filer",
    "Uploading..." : "Laddar upp...",
    "Nothing shared with you yet" : "Inget delat med dig ännu",
    "Files and folders others share with you will show up here" : "Filer och mappar andra delar med dig kommer visas här",
    "Nothing shared yet" : "Inget delat ännu",
    "Files and folders you share will show up here" : "Filer och mappar du delar kommer visas här",
    "No shared links" : "Inga delade länkar",
    "Files and folders you share by link will show up here" : "Filer och mappar du delar som länkar kommer visas här",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vill du lägga till fjärrdelning {name} från {owner}@{remote}?",
    "Remote share" : "Fjärrdelning",
    "Remote share password" : "Lösenord för fjärrdelning",
    "Cancel" : "Avbryt",
    "Add remote share" : "Lägg till fjärrdelning",
    "You can upload into this folder" : "Du kan ladda upp i denna map",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ingen OwnCloud Installation (7 eller senare) funnen på {remote}",
    "Invalid ownCloud url" : "Felaktig ownCloud url",
    "Share" : "Dela",
    "No expiration date set" : "Inget utgångsdatum är satt",
    "Declined" : "Nekad",
    "Pending" : "Väntar",
    "Shared by" : "Delad av",
    "Sharing" : "Dela",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En publikt delad fil eller mapp blev <strong>nerladdad</strong>",
    "You received a new remote share %2$s from %1$s" : "Du har mottagit en fjärrdelning %2$s från %1$s",
    "You received a new remote share from %s" : "Du mottog en ny fjärrdelning från %s",
    "%1$s accepted remote share %2$s" : "%1$s accepterade fjärrdelning %2$s",
    "%1$s declined remote share %2$s" : "%1$s nekade fjärrdelning %2$s",
    "%1$s unshared %2$s from you" : "%1$s tog bort delningen %2$s från dig",
    "Public shared folder %1$s was downloaded" : "Publikt delad mapp %1$s blev nerladdad",
    "Public shared file %1$s was downloaded" : "Publikt delad fil %1$s blev nerladdad",
    "You shared %1$s with %2$s" : "Du delade %1$s med %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s delade %1$s med %3$s",
    "You removed the share of %2$s for %1$s" : "Du tog bort delning av %2$s för %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s tog bort delningen av %3$s för %1$s",
    "You shared %1$s with group %2$s" : "Du delade %1$s med grupp %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delade %1$s med gruppen %3$s",
    "You removed the share of group %2$s for %1$s" : "Du tog bort delningen av gruppen %2$s för %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s tog bort delningen av grupp %3$s för %1$s",
    "%2$s shared %1$s via link" : "%2$s delade %1$s via länk",
    "You shared %1$s via link" : "Du delade %1$s via länk",
    "You removed the public link for %1$s" : "Du tog bort den publika länken för %1$s",
    "%2$s removed the public link for %1$s" : "%2$s tog bort den publika länken för %1$s",
    "Your public link for %1$s expired" : "Din publika länk för %1$s har löpt ut",
    "The public link of %2$s for %1$s expired" : "Den publika länken för %2$s av %1$s har löpt ut",
    "%2$s shared %1$s with you" : "%2$s delade %1$s med dig",
    "%2$s removed the share for %1$s" : "%2$s tog bort delningen av %1$s",
    "Downloaded via public link" : "Nerladdad via publik länk",
    "Shared with %2$s" : "Delad med %2$s",
    "Shared with %3$s by %2$s" : "Delad med %3$s av %2$s",
    "Removed share for %2$s" : "Tog bort delningen för %2$s",
    "%2$s removed share for %3$s" : "%2$s tog bort delningen för %3$s",
    "Shared with group %2$s" : "Delning med grupp %2$s",
    "Shared with group %3$s by %2$s" : "Delade med grupp %3$s av %2$s",
    "Removed share of group %2$s" : "Tog bort delning av grupp %2$s",
    "%2$s removed share of group %3$s" : "%2$s tog bort delningen av grupp %3$s",
    "Shared via link by %2$s" : "Delad via länk av %2$s",
    "Shared via public link" : "Delad via publik länk",
    "Removed public link" : "Tog bort publik länk",
    "%2$s removed public link" : "%2$s tog bort publik länk",
    "Public link expired" : "Tidsgräns för publik länk har löpt ut",
    "Public link of %2$s expired" : "Tidsgräns för publik länk för %2$s har löpt ut",
    "Shared by %2$s" : "Delad av %2$s",
    "Shares" : "Delningar",
    "Public link" : "Publik länk",
    "Share API is disabled" : "Dela-API är inaktiverat",
    "Wrong share ID, share doesn't exist" : "Fel delningsid, delning existerar inte",
    "Could not delete share" : "Kunde ej ta bort delning",
    "Please specify a file or folder path" : "Vänligen ange en fil eller sökväg till mapp",
    "Wrong path, file/folder doesn't exist" : "Felaktig sökväg, fil/mapp existerar inte",
    "Invalid date, date format must be YYYY-MM-DD" : "Ogiltigt datum, datumformat måste vara YYYY-MM-DD",
    "Please specify a valid user" : "Vänligen ange en giltig användare",
    "Group sharing is disabled by the administrator" : "Gruppdelning är inaktiverat av administratören",
    "Please specify a valid group" : "Vänligen ange en giltig grupp",
    "Public link sharing is disabled by the administrator" : "Publik länkdelning är inaktiverat av administratören",
    "Public upload disabled by the administrator" : "Publik uppladdning är inaktiverad av administratören",
    "Public upload is only possible for publicly shared folders" : "Publik uppladdning är enbart möjligt för publikt delade mappar",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delning %s misslyckades därför att \"back-end-sidan\" inte tillåter delningar av typen %s",
    "Unknown share type" : "Okänd delningstyp",
    "Not a directory" : "Inte en mapp",
    "Could not lock path" : "Kunde inte låsa sökväg",
    "Can't change permissions for public share links" : "Kan inte ändra rättigheter på publika delningslänkar",
    "Accept" : "Acceptera",
    "Decline" : "Neka",
    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Password" : "Lösenord",
    "No entries found in this folder" : "Inga filer hittades i denna mapp",
    "Name" : "Namn",
    "Share time" : "Delningstid",
    "Expiration date" : "Utgångsdatum",
    "Sorry, this link doesn’t seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the item was removed" : "objektet togs bort",
    "the link expired" : "giltighet för länken har gått ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more info, please ask the person who sent this link." : "För mer information, kontakta den person som skickade den här länken.",
    "%s is publicly shared" : "%s är publikt delad",
    "Download" : "Ladda ner",
    "Download %s" : "Ladda ner %s",
    "Direct link" : "Direktlänk"
},
"nplurals=2; plural=(n != 1);");
